<?php
/**
 * social_section section
 *
 * This is the template for the content of social_section section
 *
 * @package Graduate_Pro
 * @since Graduate Pro 1.0
 */
if ( ! function_exists( 'graduate_pro_add_social_section_section' ) ) :
  /**
   * Add social_section section
   *
   *@since Graduate Pro 1.0
   */
  function graduate_pro_add_social_section_section() {

    // Check if social_section is enabled on frontpage
    $social_section_enable = apply_filters( 'graduate_pro_section_status', true, 'social_section_enable' );
    if ( true !== $social_section_enable ) {
      return false;
    }

    // Get social_section section details
    $section_details = array();
    $section_details = apply_filters( 'graduate_pro_filter_social_section_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render social_section section now.
    graduate_pro_render_social_section_section( $section_details );
  }
endif;
add_action( 'graduate_pro_primary_content', 'graduate_pro_add_social_section_section', 110 );


if ( ! function_exists( 'graduate_pro_get_social_section_section_details' ) ) :
    /**
    * social_section section details.
    *
    * @since Graduate Pro 1.0
    * @param array $input social_section section details.
    */
    function graduate_pro_get_social_section_section_details( $input ) {
        $options = graduate_pro_get_theme_options();

        // social_section type
        $social_section_type  = $options['social_section_content_type'];

        $content = array();
        switch ( $social_section_type ) {
            case 'demo':

                $title = array( esc_html__( 'Facebook', 'graduate-pro' ), esc_html__( 'Twitter', 'graduate-pro' ), esc_html__( 'Youtube', 'graduate-pro' ), esc_html__( 'Instagram', 'graduate-pro' ) );
                $url = array( esc_html__( 'facebook.com', 'graduate-pro' ), esc_html__( 'twitter.com', 'graduate-pro' ), esc_html__( 'youtube.com', 'graduate-pro' ), esc_html__( 'instagram.com', 'graduate-pro' ) );
                for( $i = 0; $i <= 3; $i++ ) {
                    $content[$i]['title']  = sprintf( '%s', 'graduate-pro', $title[$i] );;
                    $content[$i]['url']    = $url[$i];
                }

            break;

            case 'custom':

                for ( $i = 1; $i <= $options['social_section_count']; $i++ ) {
                    if ( ! empty( $options[ 'social_link_url_'.$i ] ) ) {
                        $content[$i]['url']          = ! empty( $options[ 'social_link_url_'.$i ] ) ? $options[ 'social_link_url_'.$i ] : '';
                        $content[$i]['title']          = ! empty( $options[ 'social_link_title_'.$i ] ) ? $options[ 'social_link_title_'.$i ] : '';
                    }
                }

            break;

            default:
            break;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// social_section section content details.
add_filter( 'graduate_pro_filter_social_section_section_details', 'graduate_pro_get_social_section_section_details' );


if ( ! function_exists( 'graduate_pro_render_social_section_section' ) ) :
    /**
    * Start social_section section
    *
    * @return string social_section content
    * @since Graduate Pro 1.0
    *
    */
    function graduate_pro_render_social_section_section( $content_details = array() ) {
        $options            = graduate_pro_get_theme_options();
        $social_title       = ! empty( $options['social_section_title'] ) ? $options['social_section_title'] : '';
        $social_background  = ! empty( $options['social_section_image'] ) ? $options['social_section_image'] : get_template_directory_uri() . '/assets/uploads/social-icons-bg.jpg';

        if ( empty( $content_details ) ) {
          return;
        } ?>

        <section id="social-menu">
            <?php if( ! empty( $social_title ) ) : ?>
                <header class="entry-header wow fadeInDown" data-wow-delay="0.1s" data-wow-duration="0.3s">
                    <h2 class="entry-title color-black"><?php echo esc_html( $social_title ); ?></h2>
                </header><!--.entry-header-->
            <?php endif; ?>
            <div class="entry-content wow fadeInUp" data-wow-delay="0.1s" data-wow-duration="0.3s" style="background-image:url( <?php echo esc_url( $social_background ); ?> ); background-size:cover;">  
                <div class="container">
                    <ul class="social-icon">
                        <?php foreach( $content_details as $content_detail ) : ?>
                            <li><a href="<?php echo esc_url( $content_detail['url'] ); ?>" title="<?php echo esc_attr( $content_detail['title'] ); ?>" ><?php echo esc_html( $content_detail['title'] ); ?></a></li>
                        <?php endforeach; ?>
                    </ul><!--.social-icon-->
                </div><!--.entry-content--> 
            </div><!-- .container -->
        </section><!--#social-icon-->
<?php 
    }
endif;